<?php

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-action.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-user-meta.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/models/class-servicetrade-options.php';

/**
 * Returns the list of users that requested access to the service trade portal.
 *
 * An action class.
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest/actions
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Service_Portal_Admin_Actions_Rest_Users_Post_Action extends Servicetrade_Action {

  private $username;
  private $email;
  private $password;
  private $can_request_service;
  private $can_view_quotes;
  private $can_view_deficiencies;
  private $can_view_prices;

  public function __construct($username,
                              $email,
                              $password,
                              $can_request_service,
                              $can_view_quotes,
                              $can_view_deficiencies,
                              $can_view_prices) {
    $this->username = $username;
    $this->email =$email;
    $this->password = $password;
    $this->can_request_service = $can_request_service && Servicetrade_Models_ServiceTrade_Options::get_request_service();
    $this->can_view_quotes = $can_view_quotes;
    $this->can_view_deficiencies = $can_view_deficiencies;
    $this->can_view_prices = $can_view_prices;
  }

  function run() {
    // Validate basics

    if(username_exists( $this->username )) {
      return new WP_Error( 'servicetrade_user_exits', 
                           'A user with this username already exists', 
                           array( 'status' => 422, 
                                  'errors' => array( 
                                    'username' => 'A user with this username already exists'
      ) ) );
    }

    if(email_exists($this->email)) {
      return new WP_Error( 'servicetrade_email_exits', 'A user with this email already exists', array( 'status' => 422, 'errors' => array( 
        'email' => 'A user with this email already exists'
      ) ) );
    }

    $user_id = wp_create_user( $this->username, $this->password, $this->email );

    if ( is_wp_error( $user_id ) ) {
      return new WP_Error( 'servicetrade_failed_to_create_user', $user_id->get_error_message(), array( 'status' => 422 ) );
    }

    Servicetrade_User_Meta::set_user_meta_data($user_id , 
            "active",
            $this->can_request_service,
            $this->can_view_quotes,
            $this->can_view_deficiencies,
            $this->can_view_prices);


   // TODO --> add this user to servicetrade

    $result =  array(
      'user_id' => $user_id,
      'username' => $this->username,
      'email' => $this->email,
      'canRequestService' => $this->can_request_service ,
      'canViewQuotes' => $this->can_view_quotes,
      'canViewDeficiencies' => $this->can_view_deficiencies,
      'canViewPrices' => $this->can_view_prices
    );
    return new WP_REST_Response( $result, 201 );
  } 


}
