<?php

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-action.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-user-meta.php';

/**
 * Deletes a user. Only users that are in the 'subscriber' role alone can be deleted.
 * Posts will not be reassigned
 *
 * An action class.
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest/actions
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Service_Portal_Admin_Actions_Rest_Users_User_Id_Delete_Post_Action extends Servicetrade_Action {
  private $user_id;
  
  public function __construct($user_id) {
    $this->user_id = $user_id;

  }

  function run() {
    require_once(ABSPATH.'wp-admin/includes/user.php' );

    $user = get_userdata($this->user_id);
    if(!$user) {
      return new WP_Error( 'servicetrade_failed_to_retrieve_user' ,'Failed to retrieve user with id ' . $this->user_id, array( 'status' => 404 ) );
    }
    
    // Check if it is a subscriber only
    if ( !in_array( 'subscriber', (array) $user->roles ) ) {
      return new WP_Error( 'servicetrade_failed_to_validate_user_as_subscriber' ,'Only users in role subscriber can be deleted.', array( 'status' => 400 ) );
    }
    if( sizeof( (array) $user->roles) > 1) {
      return new WP_Error( 'servicetrade_failed_to_validate_user_in_single_role' ,'Only users in a single role (subscriber) can be deleted.', array( 'status' => 400 ) );      
    }

    $status_value = Servicetrade_User_Meta::get_status($this->user_id);

    // Check if it's status is not null/empty (in which it would be a wordpress only user)
    if(empty($status_value)) {
      return new WP_Error( 'servicetrade_failed_not_a_plugin_user' ,'Only users that have been created/added through the plugin can be deleted.', array( 'status' => 400 ) );
    }

    wp_delete_user( $this->user_id );

    return new WP_REST_Response( null, 200 );
  } 
}
