<?php

/**
 * Router for the WP-API Admin Interface
 *
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/admin/rest
 * @author     ServiceTrade <support@servicetrade.com>
 * @example
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/admin/users/access-requested
 *  					http://localhost:8888/wp-json/servicetrade-service-portal/v2/admin/users
 */

class Servicetrade_Service_Portal_Admin_Routes_Controller extends WP_REST_Controller {

	/**
	 * Register the routes for the objects of the controller.
	 */
	public function register_routes() {
		$version = '2';
		$namespace = 'servicetrade-service-portal/v' . $version;
		$base = 'admin';

    register_rest_route( $namespace, '/' . $base . '/users' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'users' ),
				'permission_callback' => array( $this, 'admin_permissions_check' ),
				'args'            => array(
				),
			),
		) );


    register_rest_route( $namespace, '/' . $base . '/users/access-requested' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'users_access_requested' ),
				'permission_callback' => array( $this, 'admin_permissions_check' ),
				'args'            => array(
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/users' , array(
			array(
				'methods'         => WP_REST_Server::CREATABLE,
				'callback'        => array( $this, 'users_create' ),
				'permission_callback' => array( $this, 'admin_permissions_check' ),
				'args'            => $this->get_endpoint_args_for_item_schema( true ), // <-- Probably not
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/users/(?P<id>[\d]+)/access-requested/accept', array(
			array(
				'methods'         => WP_REST_Server::CREATABLE,
				'callback'        => array( $this, 'post_users_user_id_access_requested_accept' ),
				'permission_callback' => array( $this, 'admin_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/users/(?P<id>[\d]+)/access-requested/reject', array(
			array(
				'methods'         => WP_REST_Server::CREATABLE,
				'callback'        => array( $this, 'post_users_user_id_access_requested_reject' ),
				'permission_callback' => array( $this, 'admin_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/users/(?P<id>[\d]+)/activate', array(
			array(
				'methods'         => WP_REST_Server::CREATABLE,
				'callback'        => array( $this, 'post_users_user_id_activate' ),
				'permission_callback' => array( $this, 'admin_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/users/(?P<id>[\d]+)/deactivate', array(
			array(
				'methods'         => WP_REST_Server::CREATABLE,
				'callback'        => array( $this, 'post_users_user_id_deactivate' ),
				'permission_callback' => array( $this, 'admin_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/users/(?P<id>[\d]+)/delete', array(
			array(
				'methods'         => WP_REST_Server::CREATABLE,
				'callback'        => array( $this, 'post_users_user_id_delete' ),
				'permission_callback' => array( $this, 'admin_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );

		// This should technically be a patch... but wordpress
		register_rest_route( $namespace, '/' . $base . '/users/(?P<id>[\d]+)', array(
			array(
				'methods'         => WP_REST_Server::EDITABLE,
				'callback'        => array( $this, 'put_users_user_id' ),
				'permission_callback' => array( $this, 'admin_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );
	}

	public function put_users_user_id( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'admin/rest/actions/class-rest-users-user-id-put.php';
		$action = new Servicetrade_Service_Portal_Admin_Actions_Rest_Users_User_Id_Put_Action($request->get_param( 'id' ),
														$request->get_param( 'canRequestService' ),
														$request->get_param( 'canViewQuotes' ),
														$request->get_param( 'canViewDeficiencies' ),
														$request->get_param( 'canViewPrices' ));
		return $action->run();
	}

	public function post_users_user_id_access_requested_accept( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'admin/rest/actions/class-rest-users-user-id-access-requested-accept-post.php';
		$action = new Servicetrade_Service_Portal_Admin_Actions_Rest_Users_User_Id_Access_Requested_Accept_Post_Action($request->get_param( 'id' ),
														$request->get_param( 'canRequestService' ),
														$request->get_param( 'canViewQuotes' ),
														$request->get_param( 'canViewDeficiencies' ),
														$request->get_param( 'canViewPrices' ));
		return $action->run();
	}

	public function post_users_user_id_access_requested_reject( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'admin/rest/actions/class-rest-users-user-id-access-requested-reject-post.php';
		$action = new Servicetrade_Service_Portal_Admin_Actions_Rest_Users_User_Id_Access_Requested_Reject_Post_Action($request->get_param( 'id' ));
		return $action->run();
	}

	public function post_users_user_id_activate( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'admin/rest/actions/class-rest-users-user-id-activate-post.php';
		$action = new Servicetrade_Service_Portal_Admin_Actions_Rest_Users_User_Id_Activate_Post_Action($request->get_param( 'id' ));
		return $action->run();
	}

	public function post_users_user_id_deactivate( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'admin/rest/actions/class-rest-users-user-id-deactivate-post.php';
		$action = new Servicetrade_Service_Portal_Admin_Actions_Rest_Users_User_Id_Deactivate_Post_Action($request->get_param( 'id' ));
		return $action->run();
	}

	public function post_users_user_id_delete( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'admin/rest/actions/class-rest-users-user-id-delete-post.php';
		$action = new Servicetrade_Service_Portal_Admin_Actions_Rest_Users_User_Id_Delete_Post_Action($request->get_param( 'id' ));
		return $action->run();
	}

  public function users_access_requested( ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'admin/rest/actions/class-rest-users-access-requested-get.php';
		$action = new Servicetrade_Service_Portal_Admin_Actions_Rest_Users_Access_Requested_Get_Action();
		return $action->run();
	}

  public function users() {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'admin/rest/actions/class-rest-users-get.php';
		$action = new Servicetrade_Service_Portal_Admin_Actions_Rest_Users_Get_Action();
		return $action->run();
	}

	public function users_create( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'admin/rest/actions/class-rest-users-post.php';
		$action = new Servicetrade_Service_Portal_Admin_Actions_Rest_Users_Post_Action($request->get_param( 'username' ),
																																												$request->get_param( 'email' ),
																																												$request->get_param( 'password' ),
																																												$request->get_param( 'featureRequestServiceEnabled' ) || false,
																																												$request->get_param( 'featureViewQuotesEnabled' ) || false,
																																												$request->get_param( 'featureViewDeficienciesEnabled' ) || false,
																																												$request->get_param( 'featureViewPricesEnabled' ) || false);
		return $action->run();
	}

	/**
	 * Check if a given request has access to get items
	 *
	 * @param WP_REST_Request $request Full data about the request.
	 * @return WP_Error|bool
	 */
	public function admin_permissions_check( $request ) {
		return current_user_can( 'manage_options' );
	}
}
