<?php

/**
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.8
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/includes
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Helper_Invoices {

	 /**
	 * Organizes invoices to match the frontend's render-invoice-amount-link helper
	 *
	 *
	 * @since    2.0.8
	 * @param    array    $invoices - an array of ST API invoice objects
	 * @param    int      $contactId - the customer's contact ID, for generating an invoice link view token
	 * @return   array
	 */
	public static function organize_invoices($invoices, $contactId) {

		$invoiceAmount = 0;
		$outputInvoices = [];

		$badInvoiceStatuses = ['draft', 'void']; // 'needs review' is OK because customers see them on work acks
		foreach ($invoices as $invoice) {
			$notVendorBill = $invoice['type'] !== 'vendorbill';
			if(!empty($invoice['totalPrice']) && !in_array($invoice['status'], $badInvoiceStatuses) && $notVendorBill) {
				$invoiceAmount = $invoiceAmount + $invoice['totalPrice'];

				$invoiceLinkData = ['invoiceId' => $invoice['id'], 'contactId' => $contactId];
				$encryptedInvoiceLinkData = Servicetrade_Service_Portal_Public_Authenticated_User::encryptUserData($invoiceLinkData);
				$outputInvoices[] = ['invoiceAmount' => $invoice['totalPrice'], 'invoiceLinkData' => $encryptedInvoiceLinkData];
			}
		}
		return [$invoiceAmount, $outputInvoices];
	}
}
