<?php

/**
 * Helps with the side loading.
 *
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/includes
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Helper_Sideloadmapper {


		/**
	 * Maps sideloaded ServiceTrade API data into nested format
	 *
	 * @since    1.0.0
	 * @param    array    $object - the full JSON data object returned from the API
	 * @param    string   $key - the name of the primary section (should match the API endpoint name)
	 * @param    array    $mapParams - map of sideloaded object field names to data sections, where
    *                    key = original object field name, value = sideloaded object section name
	 * @return   array
	 */
	 public static function map_sideloaded_data($object, $key, $mapParams) {
		
				$getSideloadData = function($id, $section) {
					if ( !$id || !$section || !is_array( $section ) ) {
						return null;
					}
					$filteredData = array_filter( $section, function( $row ) use ( $id ) {
						return $row['id'] == $id;
					});
					return array_shift( $filteredData );
				};
		
				$mapSectionData = function( &$object, $sectionName, $mapParams ) use ( $getSideloadData ) {
					$section = $object[$sectionName];
					foreach ( $section as $k => $v ) {
						foreach ( $v as $fieldName=>$field ) {
							$retrieveFromSection = isset( $mapParams[$fieldName] ) ? $mapParams[$fieldName] : null;
							if ( $retrieveFromSection ) {
								if ( is_array( $field ) ) {
									foreach ( $field as $idx=>$sv ) {
										$object[$sectionName][$k][$fieldName][$idx] = $getSideloadData( $sv, $object[$retrieveFromSection] );
									}
								} else if ( isset( $object[$retrieveFromSection] ) ) {
									$object[$sectionName][$k][$fieldName] = $getSideloadData( $field, $object[$retrieveFromSection] );
								}
							}
						}
					}
				};
		
		
				foreach ( $object as $sectionName => $section ) {
					if ( $sectionName != $key ) {
						$mapSectionData( $object, $sectionName, $mapParams );
					}
				}
				// map target section last, so all dependencies between other sections will be met
				$mapSectionData( $object, $key, $mapParams );
		
				return $object[$key];
			}


}
