<?php

/**
 * The credentials used to access the API.
 *
 * This is backed up by the options within wordpress
 *
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/includes/models
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Models_API_Credentials {
  public static $username_key = 'servicetrade_portal_username';
  public static $password_key = 'servicetrade_portal_password';
  public static $access_token_key = 'servicetrade_portal_access_token';

	public static function get_access_token()
	{
		$encryptedAccessToken = get_option( Servicetrade_Models_API_Credentials::$access_token_key, '' );

		return Servicetrade_Models_API_Credentials::decrypt( $encryptedAccessToken, Servicetrade_Models_API_Credentials::nonce_key() );
	}

	public static function set_access_token( $token )
	{
		$encryptedAccessToken = Servicetrade_Models_API_Credentials::encrypt( $token, Servicetrade_Models_API_Credentials::nonce_key() );

		update_option( Servicetrade_Models_API_Credentials::$access_token_key, $encryptedAccessToken );
	}



	public static function get_username()
	{
		return get_option( Servicetrade_Models_API_Credentials::$username_key, '' );
	}

	public static function set_username( $username )
	{
		update_option( Servicetrade_Models_API_Credentials::$username_key, $username );
	}

	public static function get_password()
	{
		$encryptedPassword = get_option( Servicetrade_Models_API_Credentials::$password_key,'' );

		return Servicetrade_Models_API_Credentials::decrypt($encryptedPassword, Servicetrade_Models_API_Credentials::nonce_key());
	}

	public static function encrypt_password($password) {
		return Servicetrade_Models_API_Credentials::encrypt($password, Servicetrade_Models_API_Credentials::nonce_key());
	}

	public static function decrypt_password($password) {
		return Servicetrade_Models_API_Credentials::decrypt($password, Servicetrade_Models_API_Credentials::nonce_key());
	}

  /*
  ** Private
  */

	private static function nonce_key() {
		return defined('NONCE_KEY') ? NONCE_KEY : 'servicetrade-portal-key';
	}

	private static function nonce_salt() {
		return defined('NONCE_SALT') ? NONCE_SALT : 'servicetrade-portal-salt';
	}

	private static function is_base64_encoded($data) {
		if ( base64_encode( base64_decode( $data ) ) === $data ) {
			return true;
		}
		return false;
	}

	private static function get_encryption_props() {
		$method = 'aes-256-ctr';
		$ivlen  = openssl_cipher_iv_length( $method );
		$salt   = Servicetrade_Models_API_Credentials::nonce_salt();

		return array( $method, $ivlen, $salt );
	}

	private static function encrypt($input_string, $key){
		if ( ! extension_loaded( 'openssl' ) ) {
			return $input_string;
		}

		list ( $method, $ivlen, $salt ) = Servicetrade_Models_API_Credentials::get_encryption_props();
		$iv = openssl_random_pseudo_bytes( $ivlen );
		$raw_value = openssl_encrypt( $input_string . $salt, $method, $key, 0, $iv );

		if ( ! $raw_value ) {
			return false;
		}

		$encrypted = base64_encode( $iv . $raw_value );
		//error_log( 'Encrypted: ' . $encrypted );
		return $encrypted;
	}

	private static function decrypt($encrypted_input_string, $key){
		if ( ! extension_loaded( 'openssl' ) ) {
			return $encrypted_input_string;
		}

		// If the string is not base64 encoded, then it is not encrypted (legacy passwords)
		if ( ! Servicetrade_Models_API_Credentials::is_base64_encoded( $encrypted_input_string ) ) {
			return $encrypted_input_string;
		}

		$raw_value = base64_decode( $encrypted_input_string, true );

		list ( $method, $ivlen, $salt ) = Servicetrade_Models_API_Credentials::get_encryption_props();
		$iv = substr( $raw_value, 0, $ivlen );
		$raw_value = substr( $raw_value, $ivlen );

		$value = openssl_decrypt( $raw_value, $method, $key, 0, $iv );
		if ( ! $value || substr( $value, -strlen( $salt ) ) !== $salt ) {
			return false;
		}

		$decrypted = substr( $value, 0, -strlen( $salt ) );
		//error_log( 'Decrypted: ' . $decrypted );
		return $decrypted;

	}

	public static function remove_options() {
		$options = array(
			static::$username_key,
			static::$password_key,
			static::$access_token_key
		);
		foreach ( $options as $option ) {
			delete_option ( $option );
		}
	}


}
