<?php

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-action.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/class-public-rest-action.php';

/**
 * Returns assets.
 *
 * An action class.
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest/actions
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Service_Portal_Public_Actions_Rest_Assets_Get_Action extends Servicetrade_Service_Portal_Public_Rest_Action {
  private $search;

  function __construct($search) {
    $this->search = $search;
  }

  function run() {
    $user = $this->get_authenticated_user();
    
    if(null === $user) {
      return $this->create_rest_error_not_authorized();
    }
    
    if($user->contactHasLocations()) {
  		 $stlocationid = array_map(function($l) { return $l['id']; }, $user->getContactLocations());
	  }

    if(empty($stlocationid)) {
      /**
       * No location for the specified user.
       */
      return $this->create_rest_success( array("assets" => []));
    }


    $apiResult = $this->api_get($this->build_assets_query($stlocationid));
    
    if(!isset( $apiResult['assets'] )) {
      return $this->create_rest_error_failed_request();
    }
    $assets = $apiResult['assets'];

    $mappedResults = array();
    
    foreach ($assets as $result) {
      $mappedResults[] = array(
        'id' => $result['id'],
        'uri' => $result['uri'],
        'name' => $result['name'],
        'assetType' => $result['display'],
        'locationId' => $result['location']['id'],
        'locationName' => $result['location']['name'],
        'street' => $result['location']['address']['street'],
        'city' => $result['location']['address']['city'],
        'state' => $result['location']['address']['state'],
      );
    }

    $restResponse =  array(
      "assets" => $mappedResults,
      "search" => $this->search,
    );
    return $this->create_rest_success( $restResponse);
  } 

  private function build_assets_query($stlocationid) {
    $query = array(
      locationId => $stlocationid,
      name => $this->search,
    );
    return '/asset?' . http_build_query($query);
  }
}
