<?php

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-action.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-helper-sideloadmapper.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-helper-invoices.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/class-public-rest-action.php';

/**
 * Returns the jobs at a location.
 *
 * @example
 * http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/locations/1739987/jobs
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest/actions
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Service_Portal_Public_Actions_Rest_Location_Jobs_Get_Action extends Servicetrade_Service_Portal_Public_Rest_Action {
  private $id;

	function __construct($id) {
    assert($id !== null, "An id is required.");
    $this->id = $id;
  }

  function run() {
    $user = $this->get_authenticated_user();
    if(null === $user) {
			return $this->create_rest_error_not_authorized();
		}
		$contactId = $user->getContactId();

    $query = [];
	 $params = $query ? http_build_query($query) : '';
	 $params .= '&locationId=' . $this->id;
    $params .= '&_sideload=appointment.job,job.location,job.deficiencies,appointment.clockEvents,appointment.serviceRequests,serviceRequest.serviceLine,job.invoices';
    $apiResult = $this->st_api()->get( '/appointment?'.$params );

    if(!isset( $apiResult['appointments'] )) {
      return $this->create_rest_error_failed_request();
    }
		$mapParams = [
			'job'             => 'jobs',
			'location'        => 'locations',
			'clockEvents'     => 'clockEvents',
			'serviceRequests' => 'serviceRequests',
			'serviceLine'     => 'serviceLines',
			'deficiencies'    => 'deficiencies',
			'invoices'        => 'invoices',
		];
	 $mappedData =  Servicetrade_Helper_Sideloadmapper::map_sideloaded_data( $apiResult, 'appointments', $mapParams );

    $mappedResults = array();

	 foreach ($mappedData as $result) {

		 $showCanceledAppointments = Servicetrade_Models_ServiceTrade_Options::get_show_canceled_appointments();
		 $canceledStatuses = ['canceled_by_vendor', 'canceled_by_customer'];
		 if (!$showCanceledAppointments && in_array($result['status'], $canceledStatuses)) {
			continue;
		 }

			$mappedServiceLines = array();
			$mappedServiceDescriptions = array();

			foreach ($result['serviceRequests'] as $serviceRequest) {
				if ($serviceRequest['description'] && array_intersect(['public', 'customer'], $serviceRequest['visibility'])) {
					$mappedServiceDescriptions[] = $serviceRequest['description'];
				}
				if( isset($serviceRequest['serviceLine'])) {
					$mappedServiceLines[] = array(
						'id' => $serviceRequest['serviceLine']['id'],
						'name' => $serviceRequest['serviceLine']['name'],
					);
				}
			}

			list($invoiceAmount, $invoices) = Servicetrade_Helper_Invoices::organize_invoices($result['job']['invoices'], $contactId);

			$isOnsite = false;
			$isEnroute = false;
			$onsiteStartTime = null;
			$enrouteStartTime = null;

			if($result['status'] === 'scheduled') {
				if(! empty($result['clockEvents']) ) {
					foreach ($result['clockEvents'] as $clock_event) {
						if($clock_event['type'] === 'clock-in' &&
							$clock_event['activity'] === 'onsite') {
								$isOnsite = true;
								$onsiteStartTime = $clock_event['time'];
						} else if($clock_event['type'] === 'clock-out' &&
							$clock_event['activity'] === 'onsite') {
							$isOnsite = false;
						} else if($clock_event['type'] === 'clock-in' &&
							$clock_event['activity'] === 'enroute') {
								$isEnroute = true;
								$enrouteStartTime = $clock_event['time'];
						} else if($clock_event['type'] === 'clock-out' &&
							$clock_event['activity'] === 'enroute') {
							$isEnroute = false;
						}
					}
				}
			}

			$serviceLinkData = ['jobId' => $result['job']['id'], 'contactId' => $contactId];
			$encryptedServiceLinkData = Servicetrade_Service_Portal_Public_Authenticated_User::encryptUserData($serviceLinkData);

			$jobDescription = in_array('description', $result['job']['visibility']) ? $result['job']['description'] : '';
			if (!$jobDescription) {
				$jobDescription = implode('<br />', $mappedServiceDescriptions);
			}
			$isCanceled = strpos($result['status'], 'canceled') !== false;

			$mappedResults[] = array(
				'id' => $result['id'],
				'uri' => $result['uri'],
				'serviceLinkData' => $encryptedServiceLinkData,
				'description' => $jobDescription,
				'locationName' => $result['job']['location']['name'],
				'locationId' => $result['job']['location']['id'],
				//'locationUri' => $result['job']['location']['uri'],
				'windowStart' => $result['windowStart'],
				'jobType' => $result['job']['type'],
				'jobNumber' => $result['job']['number'],
				'jobTypeDisplay' => ucwords( str_replace("_", " ", $result['job']['type'])),
				'status' => $result['status'],
				'serviceLines' => $mappedServiceLines,
				'invoiceAmount' => $invoiceAmount,
				'invoices' => $invoices,
				'isCanceled' => $isCanceled,
				'isOnsite' => $isOnsite
			);

    }

    $restResponse =  array(
      "jobs" => $mappedResults
    );
    return new WP_REST_Response( $restResponse, 200 );
  }
}
