<?php

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-action.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/class-public-rest-action.php';

/**
 * Requests a service
 *
 * An action class.
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest/actions
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Service_Portal_Public_Actions_Rest_Service_Requests_Post_Action extends Servicetrade_Service_Portal_Public_Rest_Action {
  private $locationId;
  private $assetId;
  private $serviceLineId;
  private $description;
  private $neededBy;

  function __construct($locationId, $assetId, $serviceLineId,$description,$neededBy) {
    
    $this->locationId = $locationId;
    $this->assetId = $assetId;
    $this->serviceLineId = $serviceLineId;
    $this->description = $description;
    $this->neededBy = $neededBy;

    // parent::__construct();
  }

  function run() {
	  $adminUserResult = $this->st_api()->get( '/auth', $requestData );
    if(empty($adminUserResult)) {
      $error = $this->st_api()->getLastError();
      return new WP_Error( 'servicetrade_failed_request' ,'Could not get company info for admin user',$error );
	 }
	  $vendorId = $adminUserResult['user']['company']['id'];

    $requestData =  array(
			"description" => $this->description,
			"locationId" => $this->locationId,
			"serviceLineId" => $this->serviceLineId,
			"assetId" => $this->assetId,
      "windowStart" => strtotime($this->neededBy),
      "windowEnd" => strtotime($this->neededBy),
		);

    $requestResult = $this->st_api()->post( '/servicerequest', $requestData );

    if(empty($requestResult)) {
      $error = $this->st_api()->getLastError();
      return new WP_Error( 'servicetrade_failed_request' ,'Could not create service request',$error );
	 }

	 $jobData = array(
		"locationId" => $this->locationId,
		"vendorId" => $vendorId,
		"type" => "service_call",
		"serviceRequestIds" => array( $requestResult['id'] ),
	);
	 $jobResult = $this->st_api()->post( '/job', $jobData );

    if(empty($jobResult)) {
      $error = $this->st_api()->getLastError();
      return new WP_Error( 'servicetrade_failed_request' ,'Could not create job',$error );
	 }

	 $siteName = get_bloginfo('name');
	 $siteUrl = get_bloginfo('url');

	 // email to customer
	 $currentUser = wp_get_current_user();
	 $customerEmail = $currentUser->user_email;
	 $customerName = $currentUser->user_login;
	 $customerSubject = "Service request for {$jobResult['location']['name']}";
	 $customerMessage = "Thank you for requesting a service call from {$jobResult['vendor']['name']} at {$jobResult['location']['name']}.";
	 $customerMessage .= "\n\nService details:";
	 $customerMessage .= "\n-----------------------------------------------------";
	 if ( $requestResult['asset'] && $requestResult['asset']['name'] ) {
		 $customerMessage .= "\nAsset: {$requestResult['asset']['name']}";
	 }
	 $customerMessage .= "\nDue by: " . date("m/d/Y", strtotime($this->neededBy));
	 $customerMessage .= "\nDescription: {$this->description}";
	 wp_mail( $customerEmail, $customerSubject, $customerMessage );

	 // email to admin
	 $adminEmail = Servicetrade_Models_ServiceTrade_Options::get_admin_email();
	 $adminSubject = "ServiceTrade service portal: Service request for {$jobResult['location']['name']} ({$siteName})";
	 $adminMessage = "{$customerName} ({$customerEmail}) at {$jobResult['location']['name']} has requested a service call from the ServiceTrade service portal at {$siteName} ({$siteUrl}).";
	 $adminMessage .= "\n\nService details:";
	 $adminMessage .= "\n-----------------------------------------------------";
	 if ( $requestResult['asset'] && $requestResult['asset']['name'] ) {
		 $adminMessage .= "\nAsset: {$requestResult['asset']['name']}";
	 }
	 $adminMessage .= "\nDue by: " . date("m/d/Y", strtotime($this->neededBy));
	 $adminMessage .= "\nDescription: {$this->description}";
	 $adminMessage .= "\n\nServiceTrade job: " . SERVICETRADE_WEB_URL . "/job/view?id=" . $jobResult['id'];
	 wp_mail( $adminEmail, $adminSubject, $adminMessage );

    return new WP_REST_Response( $jobResult, 201 );
  }
}
