<?php

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-action.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/models/class-servicetrade-options.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-user-meta.php';
require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/class-public-rest-action.php';

/**
 * Logs a user in.
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest/actions
 * @author     ServiceTrade <support@servicetrade.com>
 */
class Servicetrade_Service_Portal_Public_Actions_Rest_User_Login_Post_Action extends Servicetrade_Service_Portal_Public_Rest_Action {
  


  private $email;
  private $password;
  private $wpdb;

  public function __construct($email,$password, $wpdb ) {
    $this->email =$email;
    $this->password = $password;
    $this->wpdb = $wpdb;
  }

  function run() {

    $creds = array();
    $creds['user_login'] = $this->email;
    $creds['user_password'] =  $this->password;
    $creds['remember'] = true;

    $user = wp_signon( $creds, false );

	 if ( is_wp_error($user) ) {
      /**
       * That did not work out. What we do now is check
       * if the portal v1 table servicetrade_portal_users exists,
       * and if it exists, we check for the user
       */
      $v1Result = $this->check_v1_user_password ( $this->email, $this->password );

			if ($v1Result) {
        $user = $this->convert_v1_to_v2_user($v1Result);
        if ( is_wp_error($user)) {
          return $user;
        }
			} else {
				return new WP_Error( 'servicetrade_login_failed' ,'The user does not exist or you provided an invalid password.', array( 'status' => 422 ) );
      }
    }

    /*
    // At this point we are successfully logged in, 
    // Now we need to determine if we are actually allowed to use
    // the servicetrade plugin and if so where to redirect.
    */

    $result = array(
			"redirectUrl" => Servicetrade_Models_ServiceTrade_Options::get_portal_page_url() // 'http://216.245.192.187/~servicetrade/servicetrade'
    );

    Servicetrade_User_Meta::set_locations_cache($user->ID,  null);
    
    return new WP_REST_Response( $result, 200 );
  } 

  	/**
	 * Check a user's password
	 *
	 *
	 * @since     2.0.0
	 * @param     string    $username
	 * @param     string    $password
	 * @return    mixed     user record if password matches, null otherwise
	 */
	function check_v1_user_password ($username, $password )
	{
		if ( !$username || !$password ) {
			return null;
		}

		$passwordQuery = function( $username, $password ) {
			$sql = "SELECT id, email, username, see_job, see_quote, see_invoice, status FROM servicetrade_portal_users WHERE status = 'A' AND email = '" . $username . "' AND password = '" . $password . "'";
			return $this->wpdb->get_row( $sql );
		};

		// hashed
		$hashedPassword = $this->hash_password( $password );
		$result = $passwordQuery ($username, $hashedPassword );

		// unhashed
		if ( !$result ) {
			$result = $passwordQuery ($username, $password );
    }
    
    /**
     * We do not allow denied users to upgrade and return null.
     */
    if($result && $result->status !== 'A') {
      return null;
    }

		return $result;
  }

   /**
	 * Takes a V1 user row and creates a new user object
	 *
	 * @since     2.0.0
	 * @param     array    $username
	 * @return    mixed     if user creation works, the new user, otherwise null
	 */
  function convert_v1_to_v2_user($v1_user_row) {
    $username = $v1_user_row->username;
    $email = $v1_user_row->email;

    /**
     * Checking if the old username exists in the new database.
     */
    if(username_exists( $username )) {
      /**
       * The username already exists in the database
       * In this case we can't create a new one.
       */
      return new WP_Error( 'servicetrade_login_failed' ,'The username already exists and cannot be converted from v1.', array( 'status' => 422 ) );
    }

    /**
     * Checking if the old email exists in the new database.
     */
    if(email_exists($email)) {
       /**
       * The username already exists in the database
       * In this case we can't create a new one.
       */
      return new WP_Error( 'servicetrade_login_failed' ,'The email already exists and cannot be converted from v1.', array( 'status' => 422 ) );
    }

    $user_id = wp_create_user( $username, $this->password, $email );

    if(is_wp_error($user_id)) {
      /**
       * Failed to create the user for whatever reason.
       * In this case we just return an error.
       */
      return new WP_Error( 'servicetrade_login_failed' ,'This user could not be converted from v1.', array( 'status' => 422 ) );
    }

    Servicetrade_User_Meta::set_user_meta_data($user_id, 
                            $this->convert_v1_status($v1_user_row->status),
                            true,
                            true,
                            true,
                            $v1_user_row->see_prices === '1');

   $creds = array();
   $creds['user_login'] = $this->email;
   $creds['user_password'] =  $this->password;
   $creds['remember'] = true;

   $user = wp_signon( $creds, false );

   if ( ! ( is_wp_error( $user ) ) ) {
     return $user;
   } else {
    return new WP_Error( 'servicetrade_login_failed' ,'This user was converted from v1 but could not be logged in.', array( 'status' => 422 ) );
   }
  }

  function convert_v1_status($v1_status) {
    if($v1_status === 'A') {
      return 'active';
    } else {
      return 'deactivated';
    }
  }
  public function hash_password ( $password )
	{
		return md5( $password );
	}
}
