<?php

/**
 * Router for the WP-API Actions
 *
 * An action class.
 *
 * @link       http://www.servicetrade.com
 * @since      2.0.0
 * @package    Servicetrade_Service_Portal
 * @subpackage Servicetrade_Service_Portal/public/rest
 * @author     ServiceTrade <support@servicetrade.com>
 * @example
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/service-lines/for-select?include-all=1 
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/locations/for-select?include-all=1 
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/job-types/for-select?include-all=1 

 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/jobs/today 
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/jobs/upcoming 
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/jobs/upcoming?location-id=97946&service-line-id=&job-type=service_call
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/jobs/recently-completed

 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/assets
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/locations
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/locations/1739987
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/locations/1739987/assets
 *					  http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/locations/1739987/deficiencies
 * 						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/locations/1739987/servicerequests
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/assets/4938937
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/assets/1215509/deficiencies
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/assets/1215509/deficiencies?fixed=1
 * 
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/deficiencies/open
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/deficiencies/open?location-id=97906
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/quotes/open
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/quotes/open?location-id=97906
 
 *						curl -X POST http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/service-requests
 *						http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/users/access-requested
 */

require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'includes/class-servicetrade-user-meta.php';

class Servicetrade_Service_Portal_Public_Routes_Controller extends WP_REST_Controller {

	/**
	 * Register the routes for the objects of the controller.
	 */
	public function register_routes() {
		$version = '2';
		$namespace = 'servicetrade-service-portal/v' . $version;
		$base = 'public';


		// This call is always accessible without being logged in.
		// http://localhost:8888/wp-json/servicetrade-service-portal/v2/public/config
		register_rest_route( $namespace, '/' . $base . '/config' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_config' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/jobs' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_jobs' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/jobs/today' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_jobs_today' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/jobs/upcoming' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_jobs_upcoming' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
				),
			),
		) );
		register_rest_route( $namespace, '/' . $base . '/jobs/recently-completed' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_jobs_recently_completed' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
				),
			),
		) );
		register_rest_route( $namespace, '/' . $base . '/redirect/(?P<id>.+)', array(
			// this has to be fully public since it's actually a redirector for service links
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_redirect' ),
				'args'            => array(
				),
			),
		) );
		register_rest_route( $namespace, '/' . $base . '/assets' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_assets' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
				),
			),
		) );
		register_rest_route( $namespace, '/' . $base . '/locations' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_locations' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/locations/for-select' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_locations_for_select' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/service-lines/for-select' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_service_lines_for_select' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
				),
			),
		) );


		register_rest_route( $namespace, '/' . $base . '/job-types/for-select' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_job_types_for_select' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/locations/(?P<id>[\d]+)', array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_location' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/locations/(?P<id>[\d]+)/assets', array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_location_assets' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/locations/(?P<id>[\d]+)/deficiencies', array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_location_deficiencies' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/locations/(?P<id>[\d]+)/jobs', array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_location_jobs' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/locations/(?P<id>[\d]+)/servicerequests', array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_location_service_requests' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/assets/(?P<id>[\d]+)', array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_asset' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',  // <-- Check
					),
				),
			),
		) );


		register_rest_route( $namespace, '/' . $base . '/deficiencies/open' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_deficiencies_open' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/quotes/open' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_quotes_open' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
				),
			),
		) );


		register_rest_route( $namespace, '/' . $base . '/service-requests' , array(
			array(
				'methods'         => WP_REST_Server::CREATABLE,
				'callback'        => array( $this, 'create_service_request' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => $this->get_endpoint_args_for_item_schema( true ), // <-- Probably not
			),
		) );


		register_rest_route( $namespace, '/' . $base . '/user/login' , array(
			array(
				'methods'         => WP_REST_Server::CREATABLE,
				'callback'        => array( $this, 'user_login' ),
				'args'            => $this->get_endpoint_args_for_item_schema( true ), // <-- Probably not
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/user/request-access' , array(
			array(
				'methods'         => WP_REST_Server::CREATABLE,
				'callback'        => array( $this, 'user_request_access' ),
				'args'            => $this->get_endpoint_args_for_item_schema( true ), // <-- Probably not
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/user/forgot-password' , array(
			array(
				'methods'         => WP_REST_Server::CREATABLE,
				'callback'        => array( $this, 'user_forgot_password' ),
				'args'            => $this->get_endpoint_args_for_item_schema( true ), // <-- Probably not
			),
		) );

		/*
		register_rest_route( $namespace, '/' . $base . '/users/access-requested' , array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'users_access_requested' ),
				'permission_callback' => array( $this, 'admin_permissions_check' ),
				'args'            => array(
				),
			),
		) );
		*/

		register_rest_route( $namespace, '/' . $base . '/assets/(?P<id>[\d]+)/deficiencies', array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_asset_deficiencies' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );

		register_rest_route( $namespace, '/' . $base . '/assets/(?P<id>[\d]+)/servicerequests', array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_asset_service_requests' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );


		register_rest_route( $namespace, '/' . $base . '/locations/(?P<id>[\d]+)/assets/for-select', array(
			array(
				'methods'         => WP_REST_Server::READABLE,
				'callback'        => array( $this, 'get_location_assets_for_select' ),
				'permission_callback' => array( $this, 'portal_access_permissions_check' ),
				'args'            => array(
					'context'          => array(
						'default'      => 'view',
					),
				),
			),
		) );
	}


	/**
	 * Returns config information for the logged user, if any.
	 * @param WP_REST_Request $request Full data about the request.
	 * @return WP_Error|WP_REST_Response 
	 */
	public function get_config( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-config-get.php';
		$params = $request->get_params();
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Config_Get_Action();
		return $action->run();
	}

	public function get_jobs( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-jobs-get.php';

		$filterLocationId = $request->get_param( 'location-id' );
		$filterServiceLineId = $request->get_param( 'service-line-id' );
		$filterJobType = $request->get_param( 'job-type' );

		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Jobs_Get_Action($filterLocationId,$filterServiceLineId,$filterJobType);
	  return $action->run();
	}


	/**
	 * Get a collection of items
	 *
	 * @param WP_REST_Request $request Full data about the request.
	 * @return WP_Error|WP_REST_Response
	 */
	public function get_jobs_today( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-jobs-today-get.php';

		$filterLocationId = $request->get_param( 'location-id' );
		$filterServiceLineId = $request->get_param( 'service-line-id' );
		$filterJobType = $request->get_param( 'job-type' );
		
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Jobs_Today_Get_Action($filterLocationId,$filterServiceLineId,$filterJobType);
		return $action->run();
	}

	public function get_jobs_upcoming( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-jobs-upcoming-get.php';

		$filterLocationId = $request->get_param( 'location-id' );
		$filterServiceLineId = $request->get_param( 'service-line-id' );
		$filterJobType = $request->get_param( 'job-type' );

		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Jobs_Upcoming_Get_Action($filterLocationId,$filterServiceLineId,$filterJobType);
		return $action->run();
	}

	public function get_jobs_recently_completed( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-jobs-recently-completed-get.php';

		$filterLocationId = $request->get_param( 'location-id' );
		$filterServiceLineId = $request->get_param( 'service-line-id' );
		$filterJobType = $request->get_param( 'job-type' );

		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Jobs_Recently_Completed_Get_Action($filterLocationId,$filterServiceLineId,$filterJobType);
	  return $action->run();
	}

	public function get_redirect( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-redirect-get.php';

		$params = $request->get_params();
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Redirect_Get_Action($params['id']);
	  return $action->run();
	}

	public function get_assets( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-assets-get.php';
		$search = $request->get_param( 'search' );
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Assets_Get_Action($search);
		return $action->run();
	}

	public function get_locations( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-locations-get.php';
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Locations_Get_Action();
		return $action->run();
	}

	public function get_locations_for_select( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-locations-for-select-get.php';
		$includeAll = $request->get_param( 'include-all' );
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Locations_For_Select_Get_Action($includeAll);
		return $action->run();
	}

	public function get_service_lines_for_select( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-service-lines-for-select-get.php';
		$includeAll = $request->get_param( 'include-all' );
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Service_Lines_For_Select_Get_Action($includeAll);
		return $action->run();
	}

	public function get_job_types_for_select( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-job-types-for-select-get.php';
		$includeAll = $request->get_param( 'include-all' );
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Job_Types_For_Select_Get_Action($includeAll);
		return $action->run();
	}

	public function get_location( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-location-get.php';
		$params = $request->get_params();
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Location_Get_Action($params['id']);
		return $action->run();
	}

	public function get_location_assets( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-location-assets-get.php';
		$params = $request->get_params();
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Location_Assets_Get_Action($params['id']);
		return $action->run();
	}

	public function get_location_assets_for_select( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-location-assets-for-select-get.php';
		$params = $request->get_params();
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Location_Assets_For_Select_Get_Action($params['id']);
		return $action->run();
	}
	


	public function get_location_deficiencies( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-location-deficiencies-get.php';
		$id = $request->get_param( 'id' );
		$fixed = $request->get_param( 'fixed' );
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Location_Deficiencies_Get_Action($id, $fixed);
		return $action->run();
	}

	public function get_location_jobs( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-location-jobs-get.php';
		$params = $request->get_params();
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Location_Jobs_Get_Action($params['id']);
		return $action->run();

	}

	public function get_location_service_requests( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-location-servicerequests-get.php';
		$params = $request->get_params();
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Location_Servicerequests_Get_Action($params['id']);
		return $action->run();

	}

	public function get_asset( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-asset-get.php';
		$params = $request->get_params();
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Asset_Get_Action($params['id']);
		return $action->run();
	}

	public function get_deficiencies_open( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-deficiencies-open-get.php';
		$filterLocationId = $request->get_param( 'location-id' );
		$filterServiceLineId = $request->get_param( 'service-line-id' );
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Deficiencies_Open_Get_Action($filterLocationId,$filterServiceLineId);
		return $action->run();
	}

	public function get_quotes_open( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-quotes-open-get.php';
		$filterLocationId = $request->get_param( 'location-id' );
		$filterServiceLineId = $request->get_param( 'service-line-id' );
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Quotes_Open_Get_Action($filterLocationId,$filterServiceLineId);
		return $action->run();
	}

	public function create_service_request( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-service-requests-post.php';
		$locationId = $request->get_param( 'locationId' );
		$assetId = $request->get_param( 'assetId' );
		$serviceLineId = $request->get_param( 'serviceLineId' );
		$description = $request->get_param( 'description' );
		$neededBy = $request->get_param( 'neededBy' );
		
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Service_Requests_Post_Action($locationId,$assetId, $serviceLineId,$description,$neededBy);
		return $action->run();
	}

	public function user_login( $request ) {
		global $wpdb;
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-user-login-post.php';
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_User_Login_Post_Action($request->get_param( 'email' ),
																																								 $request->get_param( 'password' ),
																																								 $wpdb);
		return $action->run();
	}

	public function user_request_access( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-user-request-access-post.php';
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_User_Request_Access_Post_Action($request->get_param( 'name' ),
																																												$request->get_param( 'email' ),
																																												$request->get_param( 'password' ));
		return $action->run();
	}

	public function user_forgot_password( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-user-forgot-password-post.php';
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_User_Forgot_Password_Post_Action($request->get_param( 'email' ));
		return $action->run();
	}

	/*
	public function users_access_requested( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-users-access-requested-get.php';
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Users_Access_Requested_Get_Action();
		return $action->run();
	} */

	public function get_asset_deficiencies( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-asset-deficiencies-get.php';

		$id = $request->get_param( 'id' );
		$fixed = $request->get_param( 'fixed' );
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Asset_Deficiencies_Get_Action($id,$fixed);
		return $action->run();
	}

	public function get_asset_service_requests( $request ) {
		require_once SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR . 'public/rest/actions/class-rest-asset-servicerequests-get.php';
		$params = $request->get_params();
		$action = new Servicetrade_Service_Portal_Public_Actions_Rest_Asset_Servicerequests_Get_Action($params['id']);
		return $action->run();
	}

	/**
	 * Check if a given request has access to the portal
	 *
	 * @param WP_REST_Request $request Full data about the request.
	 * @return WP_Error|bool
	 */
	public function portal_access_permissions_check( $request ) {
		return get_current_user_id() && 
					 Servicetrade_User_Meta::get_status(get_current_user_id()) === 'active';
	}
}
