<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://www.servicetrade.com
 * @since             1.0.0
 * @package           Servicetrade_Service_Portal
 *
 * @wordpress-plugin
 * Plugin Name:       ServiceTrade Service Portal
 * Plugin URI:        http://www.servicetrade.com
 * Description:       Service portal plugin to give your customers access to their service history in ServiceTrade.
 * Version:           2.0.12
 * Requires PHP:      8.0
 * Author:            ServiceTrade
 * Author URI:        http://www.servicetrade.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       servicetrade-service-portal
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Avoid folder relative plugin paths'
 * /..../servicetrade-service-portal/
 */
define( 'SERVICETRADE_PORTAL_PLUGIN_ROOT_DIR', plugin_dir_path( __FILE__ ) );
define( 'SERVICETRADE_WEB_URL', 'https://app.servicetrade.com' );
define( 'SERVICETRADE_API_URL', 'https://api.servicetrade.com/api' );


require_once plugin_dir_path(__FILE__) . 'vendor/autoload.php';

/**
 * Checks for updates.
 */
Puc_v4_Factory::buildUpdateChecker(
	'https://extensions.servicetrade.com/releases/servicetrade-service-portal.json',
	__FILE__,
	'servicetrade-service-portal'
);

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-servicetrade-portal-activator.php
 */
function activate_Servicetrade_Service_Portal() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-servicetrade-portal-activator.php';
	Servicetrade_Service_Portal_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-servicetrade-portal-deactivator.php
 */
function deactivate_Servicetrade_Service_Portal() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-servicetrade-portal-deactivator.php';
	Servicetrade_Service_Portal_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_Servicetrade_Service_Portal' );
register_deactivation_hook( __FILE__, 'deactivate_Servicetrade_Service_Portal' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-servicetrade-portal.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_Servicetrade_Service_Portal() {

	$plugin = new Servicetrade_Service_Portal();
	$plugin->run();

}
run_Servicetrade_Service_Portal();
